@@ -3,6 +3,7 @@
 # ----------------------------------------------------------------------------------------------------------------------
 # General Packages
 from __future__ import annotations
+import itertools
 
 # Custom Library
 
@@ -23,10 +24,17 @@ class CSSElement:
 
     def __init__(self, *parts, defined_name=None):
         self.defined_name = defined_name
-        self.parts = list(x for x in (self.defined_name, *parts) if x is not None)
+        self.parts = list(parts)
 
     def __str__(self) -> str:
-        return ''.join(str(p) for p in self.parts)
+        return ''.join(str(p) for p in itertools.chain((self.defined_name,), self.parts) if p is not None)
 
     def __call__(self, *parts):
-        return self.__class__(*parts, defined_name=self.defined_name)
\ No newline at end of file
+        parts_ = []
+        for p in parts:
+            if type(p) is type(self):
+                parts_.extend(p.parts)
+            else:
+                parts_.append(p)
+
+        return self.__class__(*self.parts, *parts_, defined_name=self.defined_name)
\ No newline at end of file
